import type { DidRegistrar, DidResolver } from './domain';
/**
 * DidsModuleConfigOptions defines the interface for the options of the DidsModuleConfig class.
 * This can contain optional parameters that have default values in the config class itself.
 */
export interface DidsModuleConfigOptions {
    /**
     * List of did registrars that should be used by the dids module. The registrar must
     * be an instance of the {@link DidRegistrar} interface.
     *
     * If no registrars are provided, the default registrars will be used. The `PeerDidRegistrar` will ALWAYS be
     * registered, as it is needed for the connections and out of band module to function. Other did methods can be
     * disabled.
     *
     * @default [KeyDidRegistrar, IndySdkSovDidRegistrar, PeerDidRegistrar]
     */
    registrars?: DidRegistrar[];
    /**
     * List of did resolvers that should be used by the dids module. The resolver must
     * be an instance of the {@link DidResolver} interface.
     *
     * If no resolvers are provided, the default resolvers will be used. The `PeerDidResolver` will ALWAYS be
     * registered, as it is needed for the connections and out of band module to function. Other did methods can be
     * disabled.
     *
     * @default [IndySdkSovDidResolver, WebDidResolver, KeyDidResolver, PeerDidResolver]
     */
    resolvers?: DidResolver[];
}
export declare class DidsModuleConfig {
    private options;
    private _registrars;
    private _resolvers;
    constructor(options?: DidsModuleConfigOptions);
    /** See {@link DidsModuleConfigOptions.registrars} */
    get registrars(): DidRegistrar[];
    addRegistrar(registrar: DidRegistrar): void;
    /** See {@link DidsModuleConfigOptions.resolvers} */
    get resolvers(): DidResolver[];
    addResolver(resolver: DidResolver): void;
}
